@@ -278,14 +278,32 @@ class Botoy:
         setattr(context, "_port", self.config.port)
         self.pool.submit(self._event_context_distributor, context)
 
+    def group_msg_handler(self, msg: dict):
+        """群消息入口函数
+        :param msg: 完整的消息数据
+        """
+        return self._group_msg_handler(msg)
+
+    def friend_msg_handler(self, msg: dict):
+        """好友消息入口函数
+        :param msg: 完整的消息数据
+        """
+        return self._friend_msg_handler(msg)
+
+    def event_handler(self, msg: dict):
+        """事件入口函数
+        :param msg: 完整的消息数据
+        """
+        return self._event_handler(msg)
+
     def run(self):
         sio = socketio.Client()
 
         sio.event(self.connect)
         sio.event(self.disconnect)
-        sio.on("OnGroupMsgs")(self._group_msg_handler)
-        sio.on("OnFriendMsgs")(self._friend_msg_handler)
-        sio.on("OnEvents")(self._event_handler)
+        sio.on("OnGroupMsgs")(self._group_msg_handler)  # type: ignore
+        sio.on("OnFriendMsgs")(self._friend_msg_handler)  # type: ignore
+        sio.on("OnEvents")(self._event_handler)  # type: ignore
 
         logger.info("Connecting to the server...")
         try:
